==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LifecycleExpirationPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LifecycleExpirationPolicyRuleCondition
 */
@JsonPropertyOrder({ LifecycleExpirationPolicyRuleCondition.JSON_PROPERTY_LIFECYCLE_STATUS,
        LifecycleExpirationPolicyRuleCondition.JSON_PROPERTY_NUMBER,
        LifecycleExpirationPolicyRuleCondition.JSON_PROPERTY_UNIT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LifecycleExpirationPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LIFECYCLE_STATUS = "lifecycleStatus";
    private String lifecycleStatus;

    public static final String JSON_PROPERTY_NUMBER = "number";
    private Integer number;

    public static final String JSON_PROPERTY_UNIT = "unit";
    private String unit;

    public LifecycleExpirationPolicyRuleCondition() {
    }

    public LifecycleExpirationPolicyRuleCondition lifecycleStatus(String lifecycleStatus) {

        this.lifecycleStatus = lifecycleStatus;
        return this;
    }

    /**
     * Get lifecycleStatus
     *
     * @return lifecycleStatus
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LIFECYCLE_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLifecycleStatus() {
        return lifecycleStatus;
    }

    @JsonProperty(JSON_PROPERTY_LIFECYCLE_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLifecycleStatus(String lifecycleStatus) {
        this.lifecycleStatus = lifecycleStatus;
    }

    public LifecycleExpirationPolicyRuleCondition number(Integer number) {

        this.number = number;
        return this;
    }

    /**
     * Get number
     *
     * @return number
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NUMBER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getNumber() {
        return number;
    }

    @JsonProperty(JSON_PROPERTY_NUMBER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNumber(Integer number) {
        this.number = number;
    }

    public LifecycleExpirationPolicyRuleCondition unit(String unit) {

        this.unit = unit;
        return this;
    }

    /**
     * Get unit
     *
     * @return unit
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UNIT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getUnit() {
        return unit;
    }

    @JsonProperty(JSON_PROPERTY_UNIT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUnit(String unit) {
        this.unit = unit;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LifecycleExpirationPolicyRuleCondition lifecycleExpirationPolicyRuleCondition = (LifecycleExpirationPolicyRuleCondition) o;
        return Objects.equals(this.lifecycleStatus, lifecycleExpirationPolicyRuleCondition.lifecycleStatus)
                && Objects.equals(this.number, lifecycleExpirationPolicyRuleCondition.number)
                && Objects.equals(this.unit, lifecycleExpirationPolicyRuleCondition.unit);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(lifecycleStatus, number, unit);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LifecycleExpirationPolicyRuleCondition {\n");
        sb.append("    lifecycleStatus: ").append(toIndentedString(lifecycleStatus)).append("\n");
        sb.append("    number: ").append(toIndentedString(number)).append("\n");
        sb.append("    unit: ").append(toIndentedString(unit)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/LifecycleExpirationPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LifecycleExpirationPolicyRuleCondition
 */
@JsonPropertyOrder({ LifecycleExpirationPolicyRuleCondition.JSON_PROPERTY_LIFECYCLE_STATUS,
        LifecycleExpirationPolicyRuleCondition.JSON_PROPERTY_NUMBER,
        LifecycleExpirationPolicyRuleCondition.JSON_PROPERTY_UNIT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LifecycleExpirationPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LIFECYCLE_STATUS = "lifecycleStatus";
    private String lifecycleStatus;

    public static final String JSON_PROPERTY_NUMBER = "number";
    private Integer number;

    public static final String JSON_PROPERTY_UNIT = "unit";
    private String unit;

    public LifecycleExpirationPolicyRuleCondition() {
    }

    public LifecycleExpirationPolicyRuleCondition lifecycleStatus(String lifecycleStatus) {

        this.lifecycleStatus = lifecycleStatus;
        return this;
    }

    /**
     * Get lifecycleStatus
     *
     * @return lifecycleStatus
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LIFECYCLE_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLifecycleStatus() {
        return lifecycleStatus;
    }

    @JsonProperty(JSON_PROPERTY_LIFECYCLE_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLifecycleStatus(String lifecycleStatus) {
        this.lifecycleStatus = lifecycleStatus;
    }

    public LifecycleExpirationPolicyRuleCondition number(Integer number) {

        this.number = number;
        return this;
    }

    /**
     * Get number
     *
     * @return number
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NUMBER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getNumber() {
        return number;
    }

    @JsonProperty(JSON_PROPERTY_NUMBER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNumber(Integer number) {
        this.number = number;
    }

    public LifecycleExpirationPolicyRuleCondition unit(String unit) {

        this.unit = unit;
        return this;
    }

    /**
     * Get unit
     *
     * @return unit
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UNIT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getUnit() {
        return unit;
    }

    @JsonProperty(JSON_PROPERTY_UNIT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUnit(String unit) {
        this.unit = unit;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LifecycleExpirationPolicyRuleCondition lifecycleExpirationPolicyRuleCondition = (LifecycleExpirationPolicyRuleCondition) o;
        return Objects.equals(this.lifecycleStatus, lifecycleExpirationPolicyRuleCondition.lifecycleStatus)
                && Objects.equals(this.number, lifecycleExpirationPolicyRuleCondition.number)
                && Objects.equals(this.unit, lifecycleExpirationPolicyRuleCondition.unit);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(lifecycleStatus, number, unit);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LifecycleExpirationPolicyRuleCondition {\n");
        sb.append("    lifecycleStatus: ").append(toIndentedString(lifecycleStatus)).append("\n");
        sb.append("    number: ").append(toIndentedString(number)).append("\n");
        sb.append("    unit: ").append(toIndentedString(unit)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
